pub struct ExploreServersPopover {
pub(super) listbox: TemplateChild<ListBox>,
server_entry: TemplateChild<Entry>,
session: WeakRef<Session>,
server_list: ExploreServerList,
selected_server: PhantomData<Option<ExploreServer>>,
}Fields
listbox: TemplateChild<ListBox>server_entry: TemplateChild<Entry>session: WeakRef<Session>The current session.
server_list: ExploreServerListThe server list.
selected_server: PhantomData<Option<ExploreServer>>The selected server, if any.
Implementations
Sourceimpl ExploreServersPopover
impl ExploreServersPopover
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl ExploreServersPopover
impl ExploreServersPopover
Sourcefn set_session(&self, session: &Session)
fn set_session(&self, session: &Session)
Set the current session.
Sourcefn selected_server_changed(&self)
fn selected_server_changed(&self)
Handle when the selected server has changed.
Sourcefn server_activated(&self)
fn server_activated(&self)
Handle when the user selected a server.
Sourcefn selected_server(&self) -> Option<ExploreServer>
fn selected_server(&self) -> Option<ExploreServer>
The server that is currently selected, if any.
Sourcefn can_add_server(&self) -> bool
fn can_add_server(&self) -> bool
Whether the server currently in the text entry can be added.
Sourcefn update_add_server_state(&self)
fn update_add_server_state(&self)
Update the state of the action to add a server according to the current state.
Sourcefn add_server(&self)
fn add_server(&self)
Add the server currently in the text entry.
Sourcefn remove_server(&self, server_name: &ServerName)
fn remove_server(&self, server_name: &ServerName)
Remove the given server.